##### CODE ACCOMPANYING MANUSCRIPT "Hughes et al. 2022. The homogenisation of 
## avian morphological and phylogenetic diversity under the global extinction 
## crisis. Current Biology."

### INDEX
## 1: Morphoscape calculations
  ## a) Figure 1: Distance to centroid for each IUCN category
        # Datasets required: traitmatrix.csv, IUCN.csv*
        # !!!!! *IUCN.csv is not provided by us here as it is derived from data 
          # downloaded with permission granted from IUCN Red List
  ## b) Figure S1: Distance to centroid for each IUCN category
        # Datasets required: traitmatrix.csv, IUCN.csv*
        # !!!!! *IUCN.csv is not provided by us here as it is derived from data 
        # downloaded with permission granted from IUCN Red List
  ## c) Calculating phylogenetic signal across morphospace
        # Datasets required: traitmatrix.csv, AllbirdsHackett1.tre**
        # !!!!! **Trees with the Hackett backbone can be downloaded from 
          # http://birdtree.org/ (Jetz et al. 2012)

## 2: Global analysis
  ## a) Morphological diversity
        # Info to generate Table S1
        # Calculating global mean distance to centroid and SES after species 
          # in each IUCN category are dropped.
        # Datasets required: traitmatrix.csv, IUCN.csv*
        # !!!!! *IUCN.csv is not provided by us here as it is derived from data 
          # downloaded with permission granted from IUCN Red List
  ## b) Phylogenetic diversity
        # Calculating global phylogenetic diversity and SES after species 
          # in each IUCN category are dropped.
        # Datasets required: IUCN.csv*, AllbirdsHackett1.tre**
        # !!!!! *IUCN.csv is not provided by us here as it is derived from data 
          # downloaded with permission granted from IUCN Red List
        # !!!!! **Trees with the Hackett backbone can be downloaded from 
          #http://birdtree.org/ (Jetz et al. 2012)
    ## c) Figure 2: Predicted loss of PD and trait diversity with IUCN loss
      # Datasets required: "Global_PD.csv", "Global_Mean_DistCent.csv"

## 3: Spatial figures
  ### The metrics were calculated for each biome and ecoregion as defined by
   # Olson et al. 2001. The same code in section 1 was used. Code provided in 
   # this section is to plot figures 3 and 4 and can be adapted to produce the 
   # supplemental figures.
   # Datasets required: Trimmed_50km_Behrmann.rds, biome_values.csv,
    # ecoregion_traitdiv_values.csv, ecoregion_PDvalues.csv
  ## a) biomes
  ## b) ecoregions


library(dispRity)

library(ape)
library(PhyloMeasures)
library(motmot)

library(raster)

library(dplyr)
library(ggrepel)
library(ggplot2)
library(viridis)
library(ggthemes)
library(ggpubr)
library(ggpointdensity)
library(patchwork)
library(ggspatial)


#Set working directory
setwd("/Users/emmahughes/Google Drive/My Drive/PhD/Chapter 3/DATA/TO_ARCHIVE/")

####################
### 1: MORPHOSPACE CALCULATIONS
####################
## a) Figure 1

## Raw files required
# Matrix containing PCs:
trait <- as.matrix(read.csv("traitmatrix.csv", row.names = 1))
# Species matched to IUCN categories:
IUCN <- read.csv("IUCN.csv", stringsAsFactors = FALSE)

rownames(trait) <- gsub("_", " ", rownames(trait))

### PC 1 - 8
traits <- trait[,1:8]
distances <- as.data.frame(dispRity(traits, metric= centroids)$disparity[[1]][[1]])
distances$IUCN <- IUCN$IUCN_mean[match(rownames(distances), IUCN$Jetz_latin)]

alldist <- distances
alldist$IUCN <- c("All")

all <- rbind(distances, alldist)

pdf("Fig1Distance_vs_IUCN.pdf", width = 4, height = 4)
ggplot(all, aes(x=IUCN, y=V1, fill=IUCN)) +
  geom_boxplot() +
  scale_x_discrete(limits=c("CR", "EN", "VU", "NT", "LC", "All")) +
  scale_fill_manual(values=c("grey", "#521913","#CE2220","#7EB875","#D0B440","#E67F33")) +
  ylab("Distance to Centroid (PC1-8)") + xlab("IUCN") + 
  theme_base(base_size=14)+
  theme(legend.position = "none")
dev.off()

####################
## b) Figure S1

## Raw files required
# Matrix containing PCs:
traitmatrix <- read.csv("traitmatrix.csv", row.names = 1)
# Species matched to IUCN categories:
IUCN <- read.csv("IUCN.csv", stringsAsFactors = FALSE)

row.names(traitmatrix) <- gsub("_", " ", rownames(traitmatrix))

CR <- IUCN$Jetz_latin[IUCN$IUCN_mean == "CR"]
EN <- IUCN$Jetz_latin[IUCN$IUCN_mean == "EN"]
VU <- IUCN$Jetz_latin[IUCN$IUCN_mean == "VU"]
NT <- IUCN$Jetz_latin[IUCN$IUCN_mean == "NT"]
LC <- IUCN$Jetz_latin[IUCN$IUCN_mean == "LC"]

CR_matrix <- traitmatrix[row.names(traitmatrix) %in% CR,]
EN_matrix <- traitmatrix[row.names(traitmatrix) %in% EN,]
VU_matrix <- traitmatrix[row.names(traitmatrix) %in% VU,]
NT_matrix <- traitmatrix[row.names(traitmatrix) %in% NT,]
LC_matrix <- traitmatrix[row.names(traitmatrix) %in% LC,]

####CR
E <- ggplot(data = traitmatrix, mapping = aes(x = Comp.1, y = Comp.2)) +
  xlab("PC1 (35.1%)") + ylab("PC2 (10.0%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,1:2]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(CR_matrix, mapping = aes(x = Comp.1, y = Comp.2), colour = "#521913", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(breaks=c(-8,-4,0,4), 
                     labels=c("-8","-4","0","4")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

FF <- ggplot(data = traitmatrix, mapping = aes(x = Comp.3, y = Comp.4)) +
  xlab("PC3 (9.3%)") + ylab("PC4 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,3:4]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(CR_matrix, mapping = aes(x = Comp.3, y = Comp.4), colour = "#521913", size = 0.4) +
  scale_y_continuous(breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  scale_x_continuous(limits = c(-5.5,5.5),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

G <- ggplot(data = traitmatrix, mapping = aes(x = Comp.5, y = Comp.6)) +
  xlab("PC5 (9.1%)") + ylab("PC6 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,5:6]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(CR_matrix, mapping = aes(x = Comp.5, y = Comp.6), colour = "#521913", size = 0.4) +
  scale_y_continuous(limits = c(-4.5,4.5),
                     breaks=c(-4,0,4), 
                     labels=c("-4","0","4")) +
  scale_x_continuous(breaks=c(-6,0,6), 
                     labels=c("-6","0","6")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

H <- ggplot(data = traitmatrix, mapping = aes(x = Comp.7, y = Comp.8)) +
  xlab("PC7 (9.1%)") + ylab("PC8 (5.3%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,7:8]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(CR_matrix, mapping = aes(x = Comp.7, y = Comp.8), colour = "#521913", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(limits = c(-6,8),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

### EN
traitmatrix2 <- traitmatrix[!rownames(traitmatrix) %in% CR,]

I <- ggplot(data = traitmatrix2, mapping = aes(x = Comp.1, y = Comp.2)) +
  xlab("PC1 (35.1%)") + ylab("PC2 (10.0%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,1:2]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  #geom_point(EN_matrix, mapping = aes(x = Comp.1, y = Comp.2), colour = "#CE2220", size = 0.4) +
  geom_point(EN_matrix, mapping = aes(x = Comp.1, y = Comp.2), colour = "#E67F33", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(breaks=c(-8,-4,0,4), 
                     labels=c("-8","-4","0","4")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")


J <- ggplot(data = traitmatrix2, mapping = aes(x = Comp.3, y = Comp.4)) +
  xlab("PC3 (9.3%)") + ylab("PC4 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,3:4]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(EN_matrix, mapping = aes(x = Comp.3, y = Comp.4), colour = "#CE2220", size = 0.4) +
  scale_y_continuous(breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  scale_x_continuous(limits = c(-5.5,5.5),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

K <- ggplot(data = traitmatrix2, mapping = aes(x = Comp.5, y = Comp.6)) +
  xlab("PC5 (9.1%)") + ylab("PC6 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,5:6]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(EN_matrix, mapping = aes(x = Comp.5, y = Comp.6), colour = "#CE2220", size = 0.4) +
  scale_y_continuous(limits = c(-4.5,4.5),
                     breaks=c(-4,0,4), 
                     labels=c("-4","0","4")) +
  scale_x_continuous(breaks=c(-6,0,6), 
                     labels=c("-6","0","6")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

L <- ggplot(data = traitmatrix2, mapping = aes(x = Comp.7, y = Comp.8)) +
  xlab("PC7 (9.1%)") + ylab("PC8 (5.3%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,7:8]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(EN_matrix, mapping = aes(x = Comp.7, y = Comp.8), colour = "#CE2220", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(limits = c(-6,8),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

### VU
traitmatrix3 <- traitmatrix2[!rownames(traitmatrix2) %in% EN,]


M <- ggplot(data = traitmatrix3, mapping = aes(x = Comp.1, y = Comp.2)) +
  xlab("PC1 (35.1%)") + ylab("PC2 (10.0%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,1:2]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(VU_matrix, mapping = aes(x = Comp.1, y = Comp.2), colour = "#E67F33", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(breaks=c(-8,-4,0,4), 
                     labels=c("-8","-4","0","4")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

N <- ggplot(data = traitmatrix3, mapping = aes(x = Comp.3, y = Comp.4)) +
  xlab("PC3 (9.3%)") + ylab("PC4 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,3:4]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(VU_matrix, mapping = aes(x = Comp.3, y = Comp.4), colour = "#E67F33", size = 0.4) +
  scale_y_continuous(breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  scale_x_continuous(limits = c(-5.5,5.5),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

O <- ggplot(data = traitmatrix3, mapping = aes(x = Comp.5, y = Comp.6)) +
  xlab("PC5 (9.1%)") + ylab("PC6 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,5:6]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(VU_matrix, mapping = aes(x = Comp.5, y = Comp.6), colour = "#E67F33", size = 0.4) +
  scale_y_continuous(limits = c(-4.5,4.5),
                     breaks=c(-4,0,4), 
                     labels=c("-4","0","4")) +
  scale_x_continuous(breaks=c(-6,0,6), 
                     labels=c("-6","0","6")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

P <- ggplot(data = traitmatrix3, mapping = aes(x = Comp.7, y = Comp.8)) +
  xlab("PC7 (9.1%)") + ylab("PC8 (5.3%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,7:8]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(VU_matrix, mapping = aes(x = Comp.7, y = Comp.8), colour = "#E67F33", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(limits = c(-6,8),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")


### NT

traitmatrix4 <- traitmatrix3[!rownames(traitmatrix3) %in% VU,]


Q <- ggplot(data = traitmatrix4, mapping = aes(x = Comp.1, y = Comp.2)) +
  xlab("PC1 (35.1%)") + ylab("PC2 (10.0%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,1:2]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(NT_matrix, mapping = aes(x = Comp.1, y = Comp.2), colour = "#D0B440", size = 0.4) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(breaks=c(-8,-4,0,4), 
                     labels=c("-8","-4","0","4")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

R<- ggplot(data = traitmatrix4, mapping = aes(x = Comp.3, y = Comp.4)) +
  xlab("PC3 (9.3%)") + ylab("PC4 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,3:4]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(NT_matrix, mapping = aes(x = Comp.3, y = Comp.4), colour = "#D0B440", size = 0.4) +
  scale_y_continuous(breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  scale_x_continuous(limits = c(-5.5,5.5),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

S <- ggplot(data = traitmatrix4, mapping = aes(x = Comp.5, y = Comp.6)) +
  xlab("PC5 (9.1%)") + ylab("PC6 (9.1%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,5:6]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(NT_matrix, mapping = aes(x = Comp.5, y = Comp.6), colour = "#D0B440", size = 0.4) +
  scale_y_continuous(limits = c(-4.5,4.5),
                     breaks=c(-4,0,4), 
                     labels=c("-4","0","4")) +
  scale_x_continuous(breaks=c(-6,0,6), 
                     labels=c("-6","0","6")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

TT <- ggplot(data = traitmatrix4, mapping = aes(x = Comp.7, y = Comp.8)) +
  xlab("PC7 (9.1%)") + ylab("PC8 (5.3%)") +
  geom_pointdensity(adjust = sd(dist((traitmatrix[,7:8]), method = "euclidean")), size = 0.4) +
  scale_colour_continuous(low = "#9C9C9C", high = "#F0F0F0") +
  geom_point(NT_matrix, mapping = aes(x = Comp.7, y = Comp.8), colour = "#D0B440", size = 0.4 ) +
  scale_y_continuous(breaks=c(-2,0,2), 
                     labels=c("-2","0","2")) +
  scale_x_continuous(limits = c(-6,8),
                     breaks=c(-5,0,5), 
                     labels=c("-5","0","5")) +
  theme_classic(base_size = 12) +
  theme(legend.title = element_blank(), legend.position = "none")

pdf("FigureS1_PC1-8.pdf", width = 8, height = 8)
ggarrange(E,I,M,Q,
          FF,J,N,R,
          G,K,O,S,
          H,L,P,TT,
          ncol = 4, nrow = 4)
dev.off()

####################
## c) Phylogenetic signal

## Raw files required
# Read in 200 trees 
trees <- read.tree("AllBirdsHackett1.tre")[1:200]
# Matrix containing PCs:
trait <- as.matrix(read.csv("traitmatrix.csv", row.names = 1))

# 8 PCs account for >95% variation in traits
### 8 PCs
traits <- trait[,1:8]

## Hold lambda, CI, Max Likelihood, AIC, AICc
raw_out <- data.frame(MLLambda=rep(NA,200), LowerCI=NA, UpperCI=NA, MaximumLikelihood=NA, AIC=NA, AICc=NA)


for (i in 1:200) {	
  
  tree = drop.tip(phy=trees[[i]], tip=trees[[i]]$tip.label[!trees[[i]]$tip.label %in% rownames(traits)]) # with pruning
  
  y <- traits
  phy = tree
  out <- transformPhylo.ML(y, phy, model="lambda", modelCIs = TRUE)
  
  raw_out$MLLambda[i] <- out$Lambda[1,][1]
  raw_out$LowerCI[i] <- out$Lambda[1,][2]
  raw_out$UpperCI[i] <- out$Lambda[1,][3]
  raw_out$MaximumLikelihood[i] <- out$MaximumLikelihood
  raw_out$AIC[i] <- out$AIC
  raw_out$AICc[i] <- out$AICc
  
  print(i)
}

head(raw_out)


mean(raw_out$MLLambda)
mean(raw_out$LowerCI)
mean(raw_out$UpperCI)


write.csv(raw_out, "PhyloSignal.csv")


####################    
### 2: GLOBAL ANALYSIS
####################   
## a) Morphological diversity
## NB: To generate Table S1, the code below can be ran on individual PCs.
## E.g. traits <- trait[,1]


## Raw files required
# Matrix containing PCs:
trait <- as.matrix(read.csv("traitmatrix.csv", row.names = 1))
# Species matched to IUCN categories:
species <- read.csv("IUCN.csv", stringsAsFactors = FALSE)

# 8 PCs account for >95% variation in traits
### 8 PCs
traits <- trait[,1:8]
head(traits)
rownames(traits) <- gsub("_", " ", rownames(traits))

### OUTPUT DATA FRAME
res <- matrix(NA, nrow=5, ncol = 6)

a <- 1000 #change depending on number of simulations  
sims <- matrix(NA, nrow=1, ncol = a) #place to store simulations for SES


all <- species$Jetz_latin
# extract traits for species in the random community
trait_vec <- matrix(traits[all,], ncol=dim(traits)[2])
# calculate SR & Mean distance to centroid
res[1,2] <- length(all)
res[1,3] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])

noCR <- species$Jetz_latin[species$IUCN_mean != "CR"]
# extract traits for species in the random community
trait_vec <- matrix(traits[noCR,], ncol=dim(traits)[2])
# calculate SR & Mean distance to centroid
res[2,2] <- length(noCR)
res[2,3] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])

for (j in 1:ncol(sims)) {
  
  cat("\r", j, "of", ncol(sims))
  
  coms <- sample(x = all, size = length(noCR), replace = FALSE)
  trait_vec <- matrix(traits[coms,], ncol=dim(traits)[2])
  
  sims[1,j] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])
  
}

res[2,4] <- mean(sims)
res[2,5] <- sd(sims)
res[2,6] <- sd(sims)/sqrt(length(sims))

noEN <- species$Jetz_latin[species$IUCN_mean != "CR" & species$IUCN_mean != "EN"]
# extract traits for species in the random community
trait_vec <- matrix(traits[noEN,], ncol=dim(traits)[2])
# calculate SR & Mean distance to centroid
res[3,2] <- length(noEN)
res[3,3] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])


for (j in 1:ncol(sims)) {
  
  cat("\r", j, "of", ncol(sims))
  
  coms <- sample(x = all, size = length(noEN), replace = FALSE)
  trait_vec <- matrix(traits[coms,], ncol=dim(traits)[2])
  
  sims[1,j] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])
  
}

res[3,4] <- mean(sims)
res[3,5] <- sd(sims)
res[3,6] <- sd(sims)/sqrt(length(sims))

noVU <- species$Jetz_latin[species$IUCN_mean != "CR" & species$IUCN_mean != "EN" & species$IUCN_mean != "VU"]
# extract traits for species in the random community
trait_vec <- matrix(traits[noVU,], ncol=dim(traits)[2])
# calculate SR & Mean distance to centroid
res[4,2] <- length(noVU)
res[4,3] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])

for (j in 1:ncol(sims)) {
  
  cat("\r", j, "of", ncol(sims))
  
  coms <- sample(x = all, size = length(noVU), replace = FALSE)
  trait_vec <- matrix(traits[coms,], ncol=dim(traits)[2])
  
  sims[1,j] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])
  
}

res[4,4] <- mean(sims)
res[4,5] <- sd(sims)
res[4,6] <- sd(sims)/sqrt(length(sims))

noNT <- species$Jetz_latin[species$IUCN_mean != "CR" & species$IUCN_mean != "EN" & species$IUCN_mean != "VU" & species$IUCN_mean != "NT"]
# extract traits for species in the random community
trait_vec <- matrix(traits[noNT,], ncol=dim(traits)[2])
# calculate SR & Mean distance to centroid
res[5,2] <- length(noNT)
res[5,3] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])

for (j in 1:ncol(sims)) {
  
  cat("\r", j, "of", ncol(sims))
  
  coms <- sample(x = all, size = length(noNT), replace = FALSE)
  trait_vec <- matrix(traits[coms,], ncol=dim(traits)[2])
  
  sims[1,j] <- mean(dispRity(trait_vec, metric= centroids)$disparity[[1]][[1]])
  
}

res[5,4] <- mean(sims)
res[5,5] <- sd(sims)
res[5,6] <- sd(sims)/sqrt(length(sims))

res <- as.data.frame(res)

colnames(res) <- c("IUCN", "SR", "Raw", "NULL_MEAN", "NULL_SD", "NULL_SE")

res$IUCN[1] <- "All Species Retained"
res$IUCN[2] <- "CR Lost"
res$IUCN[3] <- "EN Lost"
res$IUCN[4] <- "VU Lost"
res$IUCN[5] <- "NT Lost (LC Only Retained)"

res$SR <- as.numeric(res$SR)
res$Raw <- as.numeric(res$Raw)
res$NULL_MEAN <- as.numeric(res$NULL_MEAN)
res$NULL_SD <- as.numeric(res$NULL_SD)
res$NULL_SE <- NA

res$SES <- (res$Raw - res$NULL_MEAN)/res$NULL_SD
str(res)
res$SES[1] <- 0

res$Metric <- "Trait Diversity"

write.csv(res, "Global_Mean_DistCent.csv", row.names = FALSE)


####################   
## b) Phylogenetic diversity

## Raw files required
## multiple phylogenetic trees downloaded from birdtree.org
multitree <- read.tree("AllBirdsHackett1.tre")
trees <- multitree[1:200]
# Species matched to IUCN categories:
species <- read.csv("IUCN.csv", stringsAsFactors = FALSE)


# Read in 200 trees 
trees <- read.tree("DATA/BIRDTREE/AllBirdsHackett1.tre")[1:200]

# Communities
# Read in species and IUCN categories
species <- read.csv("DATA/IUCN RED LIST/MeanIUCN_Jetz_6May21.csv", stringsAsFactors = FALSE)
species$Jetz_latin <- gsub(" ", "_", species$Jetz_latin)

# Create empty community matrix 
tips <- matrix(0, nrow=5, ncol=nrow(species))
# Assign species names to column names in community matrix
colnames(tips) <- species$Jetz_latin

# Making up some data so the communities define presence absence. Anything with a 1 is in the community

CRbirds <- species$Jetz_latin[species$IUCN_mean != "CR"]
ENbirds <- species$Jetz_latin[species$IUCN_mean != "CR" & species$IUCN_mean != "EN"]
VUbirds <- species$Jetz_latin[species$IUCN_mean != "CR"
                              & species$IUCN_mean != "EN" & species$IUCN_mean != "VU"]
NTbirds <- species$Jetz_latin[species$IUCN_mean != "CR"
                              & species$IUCN_mean != "EN" & species$IUCN_mean != "VU"
                              & species$IUCN_mean != "NT"]


tips[1, ] <- 1 
tips[2, colnames(tips) %in% CRbirds] <- 1 
tips[3, colnames(tips) %in% ENbirds] <- 1 
tips[4, colnames(tips) %in% VUbirds] <- 1 
tips[5, colnames(tips) %in% NTbirds] <- 1 

tips[1:5,1:6]

# Now calculate standardised PD
# Data frame to store ses.pd output (one row for each phylogeny, one column for each community)
ses_out <- data.frame(comm1=rep(NA,200), comm2=NA, comm3=NA, comm4=NA, comm5=NA)
# Data frame to store pd output (one row for each phylogeny, one column for each community)
raw_out <- data.frame(comm1=rep(NA,200), comm2=NA, comm3=NA, comm4=NA, comm5=NA)

#weights = runif(length(species$Jetz_latin))
weights = rep(1, length(species$Jetz_latin))
names(weights) = species$Jetz_latin

start_time <- Sys.time()
for (i in 1:200) {	
  tree = drop.tip(phy=trees[[i]], tip=trees[[i]]$tip.label[!trees[[i]]$tip.label %in% species$Jetz_latin]) # with pruning
  #pd.query(tree, matrix=tips, standardize=TRUE)
  ses_out[i,] <- pd.query(tree, matrix=tips, null.model = "sequential", abundance.weights = weights, reps = 1000, standardize=TRUE)
  raw_out[i,] <- pd.query(tree, matrix=tips, standardize=FALSE)
  print(i)
}
end_time <- Sys.time()

end_time - start_time


pd_calcs <- matrix(NA, nrow=5, ncol = 5)
pd_calcs <- as.data.frame(pd_calcs)
colnames(pd_calcs) <- c("IUCN", "SR", "Raw", "NULL_MEAN", "NULL_SD", "NULL_SE", "SES")

pd_calcs$IUCN[1] <- "All Species Retained"
pd_calcs$IUCN[2] <- "CR Lost"
pd_calcs$IUCN[3] <- "EN Lost"
pd_calcs$IUCN[4] <- "VU Lost"
pd_calcs$IUCN[5] <- "NT Lost (LC Only Retained)"

pd_calcs$Raw[1] <- mean(raw_out[,1])
pd_calcs$Raw[2] <- mean(raw_out[,2])
pd_calcs$Raw[3] <- mean(raw_out[,3])
pd_calcs$Raw[4] <- mean(raw_out[,4])
pd_calcs$Raw[5] <- mean(raw_out[,5])

pd_calcs$SES[1] <- 0
pd_calcs$SES[2] <- mean(ses_out[,2])
pd_calcs$SES[3] <- mean(ses_out[,3])
pd_calcs$SES[4] <- mean(ses_out[,4])
pd_calcs$SES[5] <- mean(ses_out[,5])


pd_calcs$NULL_SD[1] <- 0
pd_calcs$NULL_SD[2] <- sd(ses_out[,2])
pd_calcs$NULL_SD[3] <- sd(ses_out[,3])
pd_calcs$NULL_SD[4] <- sd(ses_out[,4])
pd_calcs$NULL_SD[5] <- sd(ses_out[,5])

pd_calcs$NULL_SE[1] <- 0
pd_calcs$NULL_SE[2] <- sd(ses_out[,2])/sqrt(length(ses_out[,2]))
pd_calcs$NULL_SE[3] <- sd(ses_out[,3])/sqrt(length(ses_out[,3]))
pd_calcs$NULL_SE[4] <- sd(ses_out[,4])/sqrt(length(ses_out[,4]))
pd_calcs$NULL_SE[5] <- sd(ses_out[,5])/sqrt(length(ses_out[,5]))

pd_calcs$SR[1] <- length(species$Jetz_latin)
pd_calcs$SR[2] <- length(species$Jetz_latin[species$IUCN_mean != "CR"])
pd_calcs$SR[3] <- length(species$Jetz_latin[species$IUCN_mean != "CR" & species$IUCN_mean != "EN"])
pd_calcs$SR[4] <- length(species$Jetz_latin[species$IUCN_mean != "CR"
                                            & species$IUCN_mean != "EN" & species$IUCN_mean != "VU"])
pd_calcs$SR[5] <- length(species$Jetz_latin[species$IUCN_mean != "CR"
                                            & species$IUCN_mean != "EN" & species$IUCN_mean != "VU"
                                            & species$IUCN_mean != "NT"])

pd_calcs$NULL_MEAN <- NA
pd_calcs$Metric <- "Phylogenetic Diversity"

write.csv(pd_calcs, "Global_PD.csv", row.names = FALSE)


####################   
## c) Figure 2

pd <- read.csv("Global_PD.csv")
md <- read.csv("Global_Mean_DistCent.csv")

res <- rbind(md, pd)

res$IUCN <- ordered(res$IUCN, levels = c("All Species Retained", "CR Lost", "EN Lost",
                                         "VU Lost", "NT Lost (LC Only Retained)"))


pdf("FIGURE2.pdf", width = 6, height = 4.5) 
ggplot(data = res, aes(x = SR, y = SES, colour = IUCN, shape = Metric)) + 
  geom_point(size = 2.5) + 
  scale_color_manual(name = "IUCN Status Lost", values=c("grey","#CE2220","#E67F33","#D0B440","#7EB875")) + 
  geom_hline(yintercept = 0, linetype = "dashed") +
  geom_hline(yintercept = -2, linetype = "dashed") +
  geom_errorbar(aes(ymin=SES-NULL_SD, ymax=SES+NULL_SD), position=position_dodge(0.05)) +
  ylab("Standard Effect Size") + 
  scale_y_continuous(limits = c(-17,0)) +
  xlab("Remaining Species Richness") + 
  scale_x_reverse() +
  theme_base(base_size=14)
dev.off()



####################
### 3: SPATIAL FIGURES
### The metrics were calculated for each biome and ecoregion as defined by
  # Olson et al. 2001. The same code in section 1 was used. Code provided in 
  # this section is to plot figures 3 and 4 and can be adapted to produce the 
  # supplemental figures.

####################   
## a) Biomes
## Raw files required
# Raster layer with correct projection, extent and resolution to use as template
pam <- readRDS("Trimmed_50km_Behrmann.rds")
# Dataset containing all trait and pd metrics calculated for each biome, 
# for each 50km grid cell
biome <- read.csv("biome_values.csv", stringsAsFactors = FALSE)


### Figure 3A: Overall trait diversity
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$E_All_MD)

pdf("MapBIOME_MD_Viridis.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", na.value = "NA", direction = 1, option = "D") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 


### Figure 3C: SES MEAN_DIST REMOVING CR
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$MinCR_sesMDC)

pdf("MapBIOME_SESMD_CR.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-11.6,-0.9), na.value = "NA", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 3E: SES MEAN_DIST REMOVING EN
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$MinEN_sesMD)

pdf("MapBIOMESESMD_EN.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-11.6,-0.9), na.value = "NA", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 


### Figure 3B: Overall PD
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$E_All_PD)

pdf("MapBIOME_PD_Viridis.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", na.value = "NA", direction = 1, option = "D") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 3D: SES PD REMOVING CR
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$MinCR_sesPD)

pdf("MapBIOME_SESPD_CR.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-2.2,1.5), na.value = "NA", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 3F: SES PD REMOVING EN
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(biome$MinEN_sesPD)

pdf("MapBIOME_SESPD_EN.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-2.2,1.5), na.value = "NA", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 



####################   
## b) Ecoregions

## Raw files required
# Raster layer with correct projection, extent and resolution to use as template
pam <- readRDS("Trimmed_50km_Behrmann.rds")
# Dataset containing all trait metrics calculated for each ecoregion, 
  # for each 50km grid cell
ecoregion_td <- read.csv("ecoregion_traitdiv_values.csv", stringsAsFactors = FALSE)
# Dataset containing all phylogenetic metrics calculated for each ecoregion, 
# for each 50km grid cell
ecoregion_pd <- read.csv("ecoregion_PDvalues.csv", stringsAsFactors = FALSE)


### Figure 4A: Overall MEAN_DIST
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_td$E_All_MeanDist)

pdf("MapECOREGION_MeanDist.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(2.3,4.03), na.value = "NA", direction = 1, option = "D") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 4C: SES MEAN_DIST REMOVING CR
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_td$E_LC_EN_SESMeanDist)

pdf("MapECOREGION_SESMeanDistLC-EN.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-9.2,1.75), na.value = "white", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 4E: SES MEAN_DIST REMOVING CR+EN
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_td$E_LC_VU_SESMeanDist)

pdf("MapECOREGION_SESMeanDistLC-VU.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-9.2,1.75), na.value = "white", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25)) 
dev.off() 

### Figure 4B: Overall PD
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_pd$E_All_PD)

pdf("MapECOREGION_PD_viridis.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", na.value = "NA", direction = 1, option = "D") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 4D: SES PD REMOVING CR
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_pd$MinCR_sesPD)

pdf("FIGURES/MapECOREGION_SESPD_CR.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-4.4,2.3), na.value = "white", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### Figure 4F: SES MEAN_DIST REMOVING EN
PAM_richness_raster <- pam[[2]]
crs(PAM_richness_raster) <- "+proj=cea +lat_ts=30 +units=km"
values(PAM_richness_raster) <- as.numeric(ecoregion_pd$MinEN_sesPD)

pdf("MapECOREGION_SESPD_EN.pdf", width = 9, height = 7) 
ggplot() +
  layer_spatial(PAM_richness_raster) +
  scale_fill_viridis(name="", limits = c(-4.4,2.3), na.value = "white", direction = 1, option = "G") +
  theme(legend.position = "bottom", 
        legend.text = element_text(size = 18)) +
  guides(fill = guide_colourbar(barwidth = 25))
dev.off() 

### BACKGROUND IS EDITED IN PHOTOSHOP AND THE FIGURE COMPILED IN POWERPOINT